﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Cvicenie7
{
    public partial class Form1 : Form
    {
        private Bitmap bitmap;
        Random random = new Random(DateTime.Now.Millisecond);
        List<Sinus> sinuses = new List<Sinus>();

        public Form1()
        {
            InitializeComponent();
            bitmap = new Bitmap(pictureBox1.Width, pictureBox1.Height);
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                graphics.Clear(Color.White);
            }
            DrawAxes();
        }

        private void pictureBox1_Paint(object sender, PaintEventArgs e)
        {
            e.Graphics.DrawImage(bitmap, 0, 0);
        }

        private void DrawAxes()
        {
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                Pen pen = new Pen(Color.Black, 2);
                graphics.DrawLine(pen, pictureBox1.Width / 2, 0,
                    pictureBox1.Width / 2, pictureBox1.Height);
                graphics.DrawLine(pen, 0, pictureBox1.Height / 2,
                    pictureBox1.Width, pictureBox1.Height / 2);
            }
        }

        private void addSinusToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AddForm addForm = new AddForm();
            if (addForm.ShowDialog() != DialogResult.OK)
            {
                return;
            }
            Sinus sinus = addForm.sinus;
            List <Point> points = new List<Point>();
            for (int x = -pictureBox1.Width/2; x <= pictureBox1.Width/2; x++)
            {
                int y = (int)Math.Round(-(sinus.A * Math.Sin(sinus.B * x / 20) + sinus.C) * 20) 
                    + pictureBox1.Height / 2;
                Point point = new Point(x + pictureBox1.Width / 2, y);
                points.Add(point);
            }
            
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                graphics.DrawLines(new Pen(GetRandomColor()), points.ToArray());
            }
            pictureBox1.Invalidate();
            sinuses.Add(sinus);
        }

        private Color GetRandomColor()
        {
            Color color = Color.FromArgb(random.Next(255), random.Next(255),
                random.Next(255));
            return color;
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                graphics.Clear(Color.White);
            }
            DrawAxes();
            pictureBox1.Invalidate();
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            dialog.Filter = "PNG Image (*.png)|*.png|" 
             + "Bitmap (*.bmp)|*.bmp|CSV file (*.csv)|*.csv";
            if (dialog.ShowDialog() != DialogResult.OK)
            {
                return;
            }
            if (dialog.FilterIndex == 1)
            {
                bitmap.Save(dialog.FileName, ImageFormat.Png);
            }
            else if (dialog.FilterIndex == 2)
            {
                bitmap.Save(dialog.FileName, ImageFormat.Bmp);
            }
            else
            {
                List<String> strings = new List<String>();
                foreach (Sinus sinus in sinuses) {
                    strings.Add(sinus.ToCSVString());
                }
                File.WriteAllLines(dialog.FileName, strings);
            }
        }
    }
}
